@@ -5,10 +5,10 @@ use MRO::Compat 'c3';
 package WebService::Shippo::Async;
 use Carp        ( 'confess' );
 use List::Util  ( 'any' );
-use Time::HiRes ( 'gettimeofday', 'tv_interval', 'usleep' );
+use Time::HiRes ( 'gettimeofday', 'tv_interval' );
 
 {
-    my $value = 20;
+    my $value = 60;
 
     sub timeout
     {
@@ -25,14 +25,17 @@ use Time::HiRes ( 'gettimeofday', 'tv_interval', 'usleep' );
     }
 }
 
-sub wait_while_status_in
+sub wait_if_status_in
 {
     my ( $invocant, @states ) = @_;
     my $start_time = [ gettimeofday() ];
+    my $delay = 0.5;
+    my $backoff = 0.25;
     while ( !$invocant->timeout_exceeded( $start_time ) ) {
         return $invocant
             unless any { /^$invocant->{object_status}$/ } @states;
-        usleep( 500 );
+        sleep( $delay );
+        $delay += $backoff;
         $invocant->refresh;
     }
     confess 'Asynchronus operation timed-out';
