@@ -3,13 +3,15 @@ use warnings;
 use MRO::Compat 'c3';
 
 package WebService::Shippo::Manifest;
-use base ( 'WebService::Shippo::Creator',
-           'WebService::Shippo::Fetcher',
-           'WebService::Shippo::Lister',
-           'WebService::Shippo::Resource',
+use base (
+    'WebService::Shippo::Resource',
+    'WebService::Shippo::Creator',
+    'WebService::Shippo::Fetcher',
+    'WebService::Shippo::Lister',
+
 );
 
-sub api_resource {'manifests'}
+sub api_resource { 'manifests' }
 
 package    # Hide from PAUSE
     WebService::Shippo::ManifestList;
