@@ -57,27 +57,20 @@ sub new
                 return $callbacks->smart_transform( $invocant );
             }
         }
-        elsif ( $ref_type eq 'ARRAY' ) {    # Hmmm, this may need removing!
-            return [ map { $invocant->construct_from( $_, $callbacks ) }
-                    @$response ];
-        }
-        elsif ( $response->isa( 'HTTP::Response' ) ) {
+        else {
             croak $response->status_line
                 unless $response->is_success;
             my $content = $response->decoded_content;
             my $hash    = $json->decode( $content );
             return $invocant->construct_from( $hash, $callbacks );
         }
-        else {
-            return $response;
-        }
     }
 }
 
 {
     my $value = 0;
 
-    sub PRETTY
+    sub pretty
     {
         my ( $class, $new_value ) = @_;
         return $value unless @_ > 1;
@@ -127,7 +120,7 @@ sub refresh
     sub to_json
     {
         $json->pretty
-            if PRETTY;
+            if pretty;
         return $json->encode( $_[0] );
     }
 
@@ -137,7 +130,7 @@ sub refresh
     sub to_string
     {
         $json->pretty
-            if PRETTY;
+            if pretty;
         return $json->encode( $_[0] );
     }
 }
