@@ -3,15 +3,16 @@ use warnings;
 use MRO::Compat 'c3';
 
 package WebService::Shippo::Parcel;
-use base ( 'WebService::Shippo::Creator',
-           'WebService::Shippo::Fetcher',
-           'WebService::Shippo::Lister',
-           'WebService::Shippo::Resource',
+use base (
+    'WebService::Shippo::Resource',
+    'WebService::Shippo::Creator',
+    'WebService::Shippo::Fetcher',
+    'WebService::Shippo::Lister',
 );
 
-sub api_resource {'parcels'}
+sub api_resource { 'parcels' }
 
-package    # Hide from PAUSE
+package                               # Hide from PAUSE
     WebService::Shippo::ParcelList;
 use base ( 'WebService::Shippo::ObjectList' );
 
