@@ -5,7 +5,8 @@ use MRO::Compat 'c3';
 package WebService::Shippo::Resource;
 require WebService::Shippo::Request;
 use URI::Encode ( 'uri_encode' );
-use base        ( 'WebService::Shippo::Object' );
+use MIME::Base64;
+use base ( 'WebService::Shippo::Object' );
 use constant DEFAULT_API_SCHEME  => 'https';
 use constant DEFAULT_API_HOST    => 'api.goshippo.com';
 use constant DEFAULT_API_PORT    => '443';
@@ -49,6 +50,22 @@ use constant DEFAULT_API_VERSION => 'v1';
     }
 }
 
+{
+    my @value = ();
+
+    sub api_username_password
+    {
+        my ( $class, $user, $pass ) = @_;
+        return @value unless @_ > 1;
+        @value = ( $user, $pass );
+        if ( @value ) {
+            my $header = 'Basic ' . encode_base64( join ':', @value );
+            Shippo::Request->headers->{Authorization} = $header;
+        }
+        return $class;
+    }
+}
+
 sub api_scheme { DEFAULT_API_SCHEME }
 
 sub api_host { DEFAULT_API_HOST }
